Learn R Programming

doMIsaul (version 1.0.1)

CH.sel: Number of cluster selection according to CH index

Description

Wrapper to estimate the best number of clusters according to CH index.

Usage

CH.sel(data, min.nc, max.nc, method)

Arguments

data

dataframe for which the number of cluster should be estimated.

min.nc

integer strictly higher than 1: minimum number of clusters.

max.nc

integer (>min.nc): maximum number of clusters.

method

string, clustering algorithm to use. The only available values for now are "kmed" for K-medians clustering and "kproto" for clustMixType::kproto() clustering.

Value

A list containing the selected number of clusters, the CH values and the best partition.