initiate_centers: Initiate centers for clustering algorithm
Description
Initiate centers for clustering algorithm
Usage
initiate_centers(data, N = 1000, t = 1, k, algorithms = NULL, seeds.N = NULL)
Arguments
data
Dataset that clustering will be applied on
N
Integer. Number clustering initialization (set of centers) to
generate
t
Numeric between 0 and 1. weight coefficient between only random
centers (t=1) and only centers from clustering (t=0).
k
Vector of size N containing the number of centers for each
initialization.
algorithms
list of algorithm(s) (size N * (1-t) to generate
centers if t!=1, given as characters. Possible values are "km" for
'K-means', "kmed" for 'K-medians',
"hclust.mean", "hclust.med" for hierarchical clustering with mean
or median position of the center.
seeds.N
(optional) vector of size N containing seeds for each
initialization.
Value
list of size N containing coordinates of centers for
clustering initialization.