Function from Lapidus et al. for imputing left-censored data with mice
mice.impute.cens(
y,
ry,
x,
lod.j,
lod.name = "lod",
REDRAW = FALSE,
wy = NULL,
...
)Vector to be imputed
Logical vector of length length(y) indicating the the subset
y[ry] of elements in y to which the imputation model is fitted.
The ry generally distinguishes the observed (TRUE) and
missing values (FALSE) in y.
Numeric design matrix with length(y) rows with predictors
for y. Matrix x may have no missing values.
censoring value.
suffix name used for the censored variable.
Boolean indicating whether values should be redrawn if some are over the censoring limit
Logical vector of length length(y). A TRUE value
indicates locations in y for which imputations are created.
Other named arguments.
Vector with imputed data, same type as y, and of length
sum(wy).