Learn R Programming

doMIsaul (version 1.0.1)

my_jack: Partition sorting based on Jaccard index

Description

Evaluates if all partitions are the same (and thus no consensus algorithm needed) and may pre-select partitions depending on a threshold on the Jaccard index

Usage

my_jack(data, mcons.JAC.sel = 0)

Arguments

data

dataframe containing the partitions (factors). Specifically, each column must be a partition and must be a factor.

mcons.JAC.sel

Numeric (in (0, 1)), minimum Jaccard index value between partitions to keep them (0 = all partitions kept).

Value

dataframe of partitions with only the partitions satisfying the conditions kept.