CH indexWrapper to estimate the best number of clusters according to CH index.
CH.sel(data, min.nc, max.nc, method)dataframe for which the number of cluster should be estimated.
integer strictly higher than 1: minimum number of clusters.
integer (>min.nc): maximum number of clusters.
string, clustering algorithm to use. The only available values
for now are "kmed" for K-medians clustering and
"kproto" for clustMixType::kproto() clustering.
A list containing the selected number of clusters, the CH values and the best partition.