Evaluates if all partitions are the same (and thus no consensus algorithm needed) and may pre-select partitions depending on a threshold on the Jaccard index
my_jack(data, mcons.JAC.sel = 0)dataframe containing the partitions (factors). Specifically, each column must be a partition and must be a factor.
Numeric (in (0, 1)), minimum Jaccard index value
between partitions to keep them (0 = all partitions kept).
dataframe of partitions with only the partitions satisfying the conditions kept.